@@ -1,4 +1,4 @@
-from functools import partial, singledispatch
+from functools import partial, singledispatch, wraps
 from typing import Any, Callable, List, Optional, Tuple, Union
 
 import numba
@@ -23,7 +23,23 @@ def _extract_data_buffer_as_np_array(array: pa.Array) -> np.ndarray:
     dtype = array.type.to_pandas_dtype()
     start = array.offset
     end = array.offset + len(array)
-    return np.asanyarray(array.buffers()[1]).view(dtype)[start:end]
+    if pa.types.is_boolean(array.type):
+        return np.unpackbits(
+            _buffer_to_view(array.buffers()[1]).view(np.uint8), bitorder="little"
+        )[start:end].astype(bool)
+    else:
+        return _buffer_to_view(array.buffers()[1]).view(dtype)[start:end]
+
+
+EMPTY_BUFFER_VIEW = np.array([], dtype=np.uint8)
+
+
+def _buffer_to_view(buf: Optional[pa.Buffer]) -> np.ndarray:
+    """Extract the pyarrow.Buffer as np.ndarray[np.uint8]."""
+    if buf is None:
+        return EMPTY_BUFFER_VIEW
+    else:
+        return np.asanyarray(buf).view(np.uint8)
 
 
 @njit
@@ -145,14 +161,12 @@ def _endswith(sa, needle, na, offset, out):
             out[offset + i] = 0
             continue
 
+        out[offset + i] = 1
         for j in range(needle_length):
             if sa.get_byte(i, string_length - needle_length + j) != needle.get_byte(j):
                 out[offset + i] = 0
                 break
 
-        else:
-            out[offset + i] = 1
-
 
 @njit
 def str_length(sa):
@@ -490,6 +504,20 @@ def _merge_non_aligned_bitmaps(
             result[byte_offset_result] = current & ~mask_result
 
 
+def _extract_isnull_bitmap(arr: pa.Array, offset: int, length: int):
+    """
+    Extract isnull bitmap with offset and padding.
+
+    Ensures that even when pyarrow does return an empty bitmap that a filled
+    one will be returned.
+    """
+    buf = _buffer_to_view(arr.buffers()[0])
+    if len(buf) > 0:
+        return buf[offset : offset + length]
+    else:
+        return np.full(length, fill_value=255, dtype=np.uint8)
+
+
 def _merge_valid_bitmaps(a: pa.Array, b: pa.Array) -> np.ndarray:
     """Merge two valid masks of pyarrow.Array instances.
 
@@ -505,18 +533,14 @@ def _merge_valid_bitmaps(a: pa.Array, b: pa.Array) -> np.ndarray:
         pad_a = 1
     else:
         pad_a = 0
-    valid_a = np.asanyarray(a.buffers()[0]).view(np.uint8)[
-        offset_a : offset_a + length + pad_a
-    ]
+    valid_a = _extract_isnull_bitmap(a, offset_a, length + pad_a)
 
     offset_b = b.offset // 8
     if b.offset % 8 != 0:
         pad_b = 1
     else:
         pad_b = 0
-    valid_b = np.asanyarray(b.buffers()[0]).view(np.uint8)[
-        offset_b : offset_b + length + pad_b
-    ]
+    valid_b = _extract_isnull_bitmap(b, offset_b, length + pad_b)
 
     if a.offset % 8 == 0 and b.offset % 8 == 0:
         result = valid_a & valid_b
@@ -537,3 +561,42 @@ def _merge_valid_bitmaps(a: pa.Array, b: pa.Array) -> np.ndarray:
         )
 
         return result
+
+
+def apply_per_chunk(func):
+    """Apply a function to each chunk if the input is chunked."""
+
+    @wraps(func)
+    def wrapper(arr: Union[pa.Array, pa.ChunkedArray], *args, **kwargs):
+        if isinstance(arr, pa.ChunkedArray):
+            return pa.chunked_array(
+                [func(chunk, *args, **kwargs) for chunk in arr.chunks]
+            )
+        else:
+            return func(arr, *args, **kwargs)
+
+    return wrapper
+
+
+@apply_per_chunk
+def all_true_like(arr: pa.Array) -> pa.Array:
+    """Return a boolean array with all-True with the same size as the input."""
+    valid_buffer = arr.buffers()[0]
+    if valid_buffer:
+        valid_buffer = valid_buffer.slice(arr.offset // 8)
+
+    output_offset = arr.offset % 8
+    output_length = len(arr) + output_offset
+
+    output_size = output_length // 8
+    if output_length % 8 > 0:
+        output_size += 1
+    output = np.full(output_size, fill_value=255, dtype=np.uint8)
+
+    return pa.Array.from_buffers(
+        pa.bool_(),
+        len(arr),
+        [valid_buffer, pa.py_buffer(output)],
+        arr.null_count,
+        output_offset,
+    )
