@@ -77,6 +77,12 @@ def is_arithmetic_type(arrow_dtype: pa.DataType) -> bool:
 skip_non_artithmetic_type = pytest.mark.skip_by_type_filter(
     [lambda x: not is_arithmetic_type(x)]
 )
+xfail_list_scalar_constuctor_not_implemented = pytest.mark.xfail_by_type_filter(
+    [pa.types.is_list], "constructor from scalars is not implemented for lists"
+)
+xfail_list_equals_not_implemented = pytest.mark.xfail_by_type_filter(
+    [pa.types.is_list], "== is not implemented for lists"
+)
 xfail_list_setitem_not_implemented = pytest.mark.xfail_by_type_filter(
     [pa.types.is_list], "__setitem__ is not implemented for lists"
 )
@@ -323,6 +329,16 @@ def data_missing_for_sorting(fletcher_type, fletcher_array):
     )
 
 
+@pytest.fixture(params=[None, lambda x: x])
+def sort_by_key(request):
+    """
+    Return a simple fixture for festing keys in sorting methods.
+
+    Tests None (no key) and the identity key.
+    """
+    return request.param
+
+
 class TestBaseCasting(BaseCastingTests):
     pass
 
@@ -335,6 +351,13 @@ class TestBaseConstructors(BaseConstructorsTests):
             )
         BaseConstructorsTests.test_from_dtype(self, data)
 
+    @xfail_list_scalar_constuctor_not_implemented
+    def test_series_constructor_scalar_with_index(self, data, dtype):
+        if PANDAS_GE_1_1_0:
+            BaseConstructorsTests.test_series_constructor_scalar_with_index(
+                self, data, dtype
+            )
+
 
 class TestBaseDtype(BaseDtypeTests):
     pass
@@ -411,6 +434,17 @@ class TestBaseMethodsTests(BaseMethodsTests):
     def test_value_counts(self, all_data, dropna, dtype):
         pass
 
+    @xfail_list_equals_not_implemented
+    @pytest.mark.parametrize("box", [pd.array, pd.Series, pd.DataFrame])
+    def test_equals(self, data, na_value, as_series, box):  # noqa: F811
+        if PANDAS_GE_1_1_0:
+            BaseMethodsTests.test_equals(self, data, na_value, as_series, box)
+
+    @xfail_missing_list_dict_encode
+    def test_value_counts_with_normalize(self, data):
+        if PANDAS_GE_1_1_0:
+            BaseMethodsTests.test_value_counts_with_normalize(self, data)
+
     def test_combine_le(self, data_repeated):
         # GH 20825
         # Test that combine works when doing a <= (le) comparison
@@ -452,8 +486,13 @@ class TestBaseMethodsTests(BaseMethodsTests):
 
     @pytest.mark.parametrize("ascending", [True, False])
     @xfail_bool_too_few_uniques
-    def test_sort_values(self, data_for_sorting, ascending):
-        BaseMethodsTests.test_sort_values(self, data_for_sorting, ascending)
+    def test_sort_values(self, data_for_sorting, ascending, sort_by_key):
+        if PANDAS_GE_1_1_0:
+            BaseMethodsTests.test_sort_values(
+                self, data_for_sorting, ascending, sort_by_key
+            )
+        else:
+            BaseMethodsTests.test_sort_values(self, data_for_sorting, ascending)
 
     @pytest.mark.parametrize("na_sentinel", [-1, -2])
     @xfail_bool_too_few_uniques
@@ -504,6 +543,11 @@ class TestBaseMethodsTests(BaseMethodsTests):
     def test_combine_first(self, data):
         BaseMethodsTests.test_combine_first(self, data)
 
+    @xfail_list_setitem_not_implemented
+    def test_shift_0_periods(self, data):
+        if PANDAS_GE_1_1_0:
+            BaseMethodsTests.test_shift_0_periods(self, data)
+
     def test_shift_fill_value(self, data):
         if pa.types.is_list(data.dtype.arrow_dtype):
             pytest.xfail("pandas' isna cannot cope with lists")
@@ -555,6 +599,9 @@ class TestBaseReshapingTests(BaseReshapingTests):
         ):
             # https://github.com/pandas-dev/pandas/issues/21792
             pytest.skip("pd.concat(int64, fletcher_chunked[int64] yields int64")
+        elif pa.types.is_temporal(arrow_dtype):
+            # https://github.com/pandas-dev/pandas/issues/33331
+            pytest.xfail("pd.concat(temporal, categorical) mangles dates")
         else:
             BaseReshapingTests.test_concat_mixed_dtypes(self, data)
 
